<?php
/*
Plugin Name: Get Remote URL Info
Plugin URI: http://oscardias.com/projects/get-remote-url-info/
Description: Fetches information about a remote URL and adds it into the post.
Version: 1.0.1
Author: Oscar Dias
Author URI: http://oscardias.com
License: GPL3
*/

/*  Copyright (C) 2012  Oscar de Souza Dias

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Add button to TinyMCE bar
function add_get_remote_button() {
   if ( ! current_user_can('edit_posts') && ! current_user_can('edit_pages') )
     return;
   if ( get_user_option('rich_editing') == 'true') {
     add_filter('mce_external_plugins', 'add_get_remote_tinymce_plugin');
     add_filter('mce_buttons', 'register_get_remote_button');
   }
}

add_action('init', 'add_get_remote_button');

function register_get_remote_button($buttons) {
   array_push($buttons, "|", "getremoteurlinfo");
   return $buttons;
}

function add_get_remote_tinymce_plugin($plugin_array) {
   $plugin_array['getremoteurlinfo'] = plugins_url( 'get-remote-url-info' , dirname(__FILE__) ).'/editor_plugin.js';
   return $plugin_array;
}

function getremoteurlinfo_refresh_mce($ver) {
  $ver += 3;
  return $ver;
}

add_filter( 'tiny_mce_version', 'getremoteurlinfo_refresh_mce');

// Front-end styling
function get_remote_url_info_stylesheet() {
    wp_enqueue_style('get_remote_url_info', plugins_url( 'get-remote-url-info' , dirname(__FILE__) ).'/style.css', false, '1.0');
}

add_action('wp_print_styles', 'get_remote_url_info_stylesheet');

// Editor styling
add_filter('mce_css', 'get_remote_url_editor_style');
function get_remote_url_editor_style($url) {

    if ( !empty($url) )
        $url .= ',';

    // Change the path here if using sub-directory
    $url .= plugins_url( 'get-remote-url-info' , dirname(__FILE__) ).'/style.css';

    return $url;
}

// AJAX handler
add_action('wp_ajax_get_remote_url_info', 'get_remote_url_info_callback');

function get_remote_url_info_callback() {
    // Check url value
    if(!$_POST['url']) {
        echo json_enconde(array('return' => 0));
        die();
    }

    // Get remote HTML
    $response = wp_remote_get($_POST['url']);

    // Load DOM
    $doc = new DOMDocument();
    @$doc->loadHTML($response['body']);

    $nodes = $doc->getElementsByTagName('title');
    // Return array
    $return = array();

    // Get title
    $nodes = $doc->getElementsByTagName('title');
    $return['title'] = $nodes->item(0)->nodeValue;
    
    //Get Meta Tags
    $metas = $doc->getElementsByTagName('meta');

    for ($i = 0; $i < $metas->length; $i++)
    {
        $meta = $metas->item($i);
        if($meta->getAttribute('name') == 'description')
            $return['description'] = $meta->getAttribute('content');
        else if($meta->getAttribute('property') == 'og:description') {
            if(!isset($return['description']))
                $return['description'] = $meta->getAttribute('content');
            else if(!$return['description'])
                $return['description'] = $meta->getAttribute('content');
        } else if($meta->getAttribute('property') == 'og:image')
            $return['images'] = '<img src="'.$meta->getAttribute('content').'" class="image-1 selected" />';
    }

    // Get Images
    $imgs = $doc->getElementsByTagName('img');
    
    $count = 1;

    for ($i = 0; $i < $imgs->length; $i++)
    {
        $img = $imgs->item($i);
        // Check if this is the first image
        if($return['images'] == '') {
            $return['images'] .= '<img src="'.$img->getAttribute('src').'" class="image-1 selected" />';
        } else {
            $count++;
            $return['images'] .= '<img src="'.$img->getAttribute('src').'" class="image-'.($count).'" />';
        }
    }

    $return['url'] = $_POST['url'];

    echo json_encode(
            array(
                'return' => 1,
                'title' => (isset($return['title']))?$return['title']:'',
                'description' => (isset($return['description']))?$return['description']:'',
                'images' => (isset($return['images']))?$return['images']:''
                )
            );

    die(); // this is required to return a proper result
}

add_action('wp_ajax_get_remote_upload_image', 'get_remote_upload_image_callback');

function get_remote_upload_image_callback() {
    global $post;
    global $wpdb;
    
    $image = media_sideload_image($_POST['filename'], $post->ID, strip_tags($_POST['title']));
    
    if(is_wp_error($image)) {
        echo json_encode(array(
            'result' => 0
        ));
        die();
    }    

    $image_bkp = $image;
    
    preg_match('/src=(["\'])(.*?)\1/', $image, $match);
    $url = $match[2];
    
    $url = preg_replace('/-\d+x\d+(?=\.(jpg|jpeg|png|gif)$)/i', '', $url);
    $attachment_id = $wpdb->get_var("SELECT ID FROM {$wpdb->posts} WHERE guid='$url'");

    $image = wp_get_attachment_image( $attachment_id );

    if($image) {    
        echo json_encode(array(
            'result' => 1,
            'image' => $image
        ));
    } else {
        echo json_encode(array(
            'result' => 1,
            'image' => $image_bkp
        ));
    }
    die();
}
